==> xreview_0.95.1.zip: xreview/regist.php <==
<?php
require('../../mainfile.php');
$myts =& MyTextSanitizer::getInstance();

global $xoopsUser;
sanitiza($_POST);

// ե顼
$referer = $_SERVER['HTTP_REFERER'];

// å(ե顼å)
$url_length = strlen(XOOPS_URL);
if ( XOOPS_URL == substr($referer,0,strlen(XOOPS_URL)) ) {
	// ե顼URI
	$uri = substr($referer,strlen(XOOPS_URL),strlen($referer));
} else {
	//
	redirect_header( $_SERVER['HTTP_REFERER'], 3, "" );
	exit();
}

// ---------------------------
// ѥ᡼
// ---------------------------
$comment   = $myts->stripSlashesGPC($_POST['comment']);
$nameOfUri = $myts->stripSlashesGPC($_POST['target_name']);
$point     = intval($_POST['point']);

// ---------------------------
//桼ID
// ---------------------------
$userid = $xoopsUser->getVar("uid");

// ---------------------------
// URI
// URIξ硢ɲ
// ---------------------------
$sql  = "select count(*) as count from ". $xoopsDB->prefix('xreview_uri');
$sql .= " where request_uri = '" . $uri . "'";
$res = $xoopsDB->query($sql);
if($row = $xoopsDB->fetchArray($res))
{
	$count = $row['count'];
	if ($count == 0 )
	{
		// URIϿ
		$insert_sql = "insert into ".$xoopsDB->prefix('xreview_uri');
		$insert_sql.= " (id,request_uri,review_name)";
		$insert_sql.= " values ('',".$xoopsDB->quoteString($uri).",".$xoopsDB->quoteString($nameOfUri).")";
		$res = $xoopsDB->query($insert_sql);
	}
}


// --------------------------------
// ¸ɾȤ()å
// --------------------------------
$count = 0;
$select_sql  = "select count(*) as count from ".$xoopsDB->prefix('xreview_data');
$select_sql .= " where ";
$select_sql .= " request_uri=".$xoopsDB->quoteString($uri)." ";
$select_sql .= " and ";
$select_sql .= " user_id=".intval($userid);
$select_res = $xoopsDB->query($select_sql);

$post_message = "";
// ǡ
$row = $xoopsDB->fetchArray($select_res);
if ($row['count'] == 0)
{
	// ɲ
	if($point != "") {
		$insert_sql = "insert into ".$xoopsDB->prefix('xreview_data');
		$insert_sql.= " values('',".$xoopsDB->quoteString($uri).",".intval($userid).",".$xoopsDB->quoteString($comment).",".intval($point).")";
		$res = $xoopsDB->query($insert_sql);
		$post_message = _MB_REVIEW_POSTED;
	} else {
		$post_message = _MB_REVIEW_FAILURE_POSTED;
	}
} else {
	if($point == "") {
		// ǡ
		$delete_sql  = "delete from ".$xoopsDB->prefix('xreview_data');
		$delete_sql .= " where ";
		$delete_sql .= " request_uri = ".$xoopsDB->quoteString($uri)." ";
		$delete_sql .= " and ";
		$delete_sql .= " user_id = ".intval($userid);
		$res = $xoopsDB->query($delete_sql);
		$post_message = _MB_REVIEW_DELETE_POSTED;
	} else {
		// ǡ
		$update_sql  = "update ".$xoopsDB->prefix('xreview_data');
		$update_sql .= " set ";
		$update_sql .= " comment = ".$xoopsDB->quoteString($comment).",";
		$update_sql .= " point = ".intval($point)." ";
		$update_sql .= " where ";
		$update_sql .= " request_uri = ".$xoopsDB->quoteString($uri)." ";
		$update_sql .= " and ";
		$update_sql .= " user_id = ".intval($userid);
		$res = $xoopsDB->query($update_sql);
		$post_message = _MB_REVIEW_UPDATE_POSTED;
	}
}

// 쥯
redirect_header( $_SERVER['HTTP_REFERER'], 3, $post_message );

//̥ХȺ
function sanitiza($arr)
{
	if( is_array($arr) ) {
		return array_map('sanitaize',$arr);
	}
	return str_replace("\0","",$arr);
}

?>

==> xreview_0.95.2.zip: xreview/regist.php <==
<?php
require('../../mainfile.php');
$myts =& MyTextSanitizer::getInstance();

global $xoopsUser;
sanitiza($_POST);

// ե顼
$referer = $_SERVER['HTTP_REFERER'];

// å(ե顼å)
$url_length = strlen(XOOPS_URL);
if ( XOOPS_URL == substr($referer,0,strlen(XOOPS_URL)) ) {
	// ե顼URI
	$uri = substr($referer,strlen(XOOPS_URL),strlen($referer));
} else {
	//
	redirect_header( $_SERVER['HTTP_REFERER'], 3, "" );
	exit();
}

// ---------------------------
// ѥ᡼
// ---------------------------
$comment   = $myts->stripSlashesGPC($_POST['comment']);
$nameOfUri = $myts->stripSlashesGPC($_POST['target_name']);
$point     = intval($_POST['point']);

// ---------------------------
//桼ID
// ---------------------------
$userid = $xoopsUser->getVar("uid");

// ---------------------------
// URI
// URIξ硢ɲ
// ---------------------------
$sql  = "select count(*) as count from ". $xoopsDB->prefix('xreview_uri');
$sql .= " where request_uri = '" . $uri . "'";
$res = $xoopsDB->query($sql);
if($row = $xoopsDB->fetchArray($res))
{
	$count = $row['count'];
	if ($count == 0 )
	{
		// URIϿ
		$insert_sql = "insert into ".$xoopsDB->prefix('xreview_uri');
		$insert_sql.= " (id,request_uri,review_name)";
		$insert_sql.= " values ('',".$xoopsDB->quoteString($uri).",".$xoopsDB->quoteString($nameOfUri).")";
		$res = $xoopsDB->query($insert_sql);
	}
}


// --------------------------------
// ¸ɾȤ()å
// --------------------------------
$count = 0;
$select_sql  = "select count(*) as count from ".$xoopsDB->prefix('xreview_data');
$select_sql .= " where ";
$select_sql .= " request_uri=".$xoopsDB->quoteString($uri)." ";
$select_sql .= " and ";
$select_sql .= " user_id=".intval($userid);
$select_res = $xoopsDB->query($select_sql);

$post_message = "";
// ǡ
$row = $xoopsDB->fetchArray($select_res);
if ($row['count'] == 0)
{
	// ɲ
	if($point != "") {
		$insert_sql = "insert into ".$xoopsDB->prefix('xreview_data');
		$insert_sql.= " values('',".$xoopsDB->quoteString($uri).",".intval($userid).",".$xoopsDB->quoteString($comment).",".intval($point).")";
		$res = $xoopsDB->query($insert_sql);
		$post_message = _MB_REVIEW_POSTED;
	} else {
		$post_message = _MB_REVIEW_FAILURE_POSTED;
	}
} else {
	if($point == "") {
		// ǡ
		$delete_sql  = "delete from ".$xoopsDB->prefix('xreview_data');
		$delete_sql .= " where ";
		$delete_sql .= " request_uri = ".$xoopsDB->quoteString($uri)." ";
		$delete_sql .= " and ";
		$delete_sql .= " user_id = ".intval($userid);
		$res = $xoopsDB->query($delete_sql);
		$post_message = _MB_REVIEW_DELETE_POSTED;
	} else {
		// ǡ
		$update_sql  = "update ".$xoopsDB->prefix('xreview_data');
		$update_sql .= " set ";
		$update_sql .= " comment = ".$xoopsDB->quoteString($comment).",";
		$update_sql .= " point = ".intval($point)." ";
		$update_sql .= " where ";
		$update_sql .= " request_uri = ".$xoopsDB->quoteString($uri)." ";
		$update_sql .= " and ";
		$update_sql .= " user_id = ".intval($userid);
		$res = $xoopsDB->query($update_sql);
		$post_message = _MB_REVIEW_UPDATE_POSTED;
	}
}

// 쥯
redirect_header( $_SERVER['HTTP_REFERER'], 3, $post_message );

//̥ХȺ
function sanitiza($arr)
{
	if( is_array($arr) ) {
		return array_map('sanitiza',$arr);
	}
	return str_replace("\0","",$arr);
}

?>
